@@ -38,6 +38,32 @@ class ImmutableObject(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def copy(self, **values):
+        """
+        Copy the model with ``field`` updated to new value.
+
+        Examples::
+
+            # Returns a track with a new name
+            Track(name='foo').copy(name='bar')
+            # Return an album with a new number of tracks
+            Album(num_tracks=2).copy(num_tracks=5)
+
+        :param values: the model fields to modify
+        :type values: dict
+        :rtype: new instance of the model being copied
+        """
+        data = {}
+        for key in self.__dict__.keys():
+            public_key = key.lstrip('_')
+            data[public_key] = values.pop(public_key, self.__dict__[key])
+        for key in values.keys():
+            if hasattr(self, key):
+                data[key] = values.pop(key)
+        if values:
+            raise TypeError("copy() got an unexpected keyword argument '%s'"
+                % key)
+        return self.__class__(**data)
 
 class Artist(ImmutableObject):
     """
@@ -45,6 +71,8 @@ class Artist(ImmutableObject):
     :type uri: string
     :param name: artist name
     :type name: string
+    :param musicbrainz_id: MusicBrainz ID
+    :type musicbrainz_id: string
     """
 
     #: The artist URI. Read-only.
@@ -53,6 +81,9 @@ class Artist(ImmutableObject):
     #: The artist name. Read-only.
     name = None
 
+    #: The MusicBrainz ID of the artist. Read-only.
+    musicbrainz_id = None
+
 
 class Album(ImmutableObject):
     """
@@ -64,6 +95,8 @@ class Album(ImmutableObject):
     :type artists: list of :class:`Artist`
     :param num_tracks: number of tracks in album
     :type num_tracks: integer
+    :param musicbrainz_id: MusicBrainz ID
+    :type musicbrainz_id: string
     """
 
     #: The album URI. Read-only.
@@ -75,6 +108,9 @@ class Album(ImmutableObject):
     #: The number of tracks in the album. Read-only.
     num_tracks = 0
 
+    #: The MusicBrainz ID of the album. Read-only.
+    musicbrainz_id = None
+
     def __init__(self, *args, **kwargs):
         self._artists = frozenset(kwargs.pop('artists', []))
         super(Album, self).__init__(*args, **kwargs)
@@ -103,6 +139,8 @@ class Track(ImmutableObject):
     :type length: integer
     :param bitrate: bitrate in kbit/s
     :type bitrate: integer
+    :param musicbrainz_id: MusicBrainz ID
+    :type musicbrainz_id: string
     """
 
     #: The track URI. Read-only.
@@ -126,6 +164,9 @@ class Track(ImmutableObject):
     #: The track's bitrate in kbit/s. Read-only.
     bitrate = None
 
+    #: The MusicBrainz ID of the track. Read-only.
+    musicbrainz_id = None
+
     def __init__(self, *args, **kwargs):
         self._artists = frozenset(kwargs.pop('artists', []))
         super(Track, self).__init__(*args, **kwargs)
@@ -178,31 +219,3 @@ class Playlist(ImmutableObject):
 
     def mpd_format(self, *args, **kwargs):
         return translator.playlist_to_mpd_format(self, *args, **kwargs)
-
-    def with_(self, uri=None, name=None, tracks=None, last_modified=None):
-        """
-        Create a new playlist object with the given values. The values that are
-        not given are taken from the object the method is called on.
-
-        Does not change the object on which it is called.
-
-        :param uri: playlist URI
-        :type uri: string
-        :param name: playlist name
-        :type name: string
-        :param tracks: playlist's tracks
-        :type tracks: list of :class:`Track` elements
-        :param last_modified: playlist's modification time
-        :type last_modified: :class:`datetime.datetime`
-        :rtype: :class:`Playlist`
-        """
-        if uri is None:
-            uri = self.uri
-        if name is None:
-            name = self.name
-        if tracks is None:
-            tracks = self.tracks
-        if last_modified is None:
-            last_modified = self.last_modified
-        return Playlist(uri=uri, name=name, tracks=tracks,
-            last_modified=last_modified)
